@@ -61,6 +61,7 @@ __all__ = (
     "GetMetricDataOutputTypeDef",
     "GetMetricStatisticsOutputTypeDef",
     "GetMetricWidgetImageOutputTypeDef",
+    "LabelOptionsTypeDef",
     "ListDashboardsOutputTypeDef",
     "ListMetricsOutputTypeDef",
     "ListTagsForResourceOutputTypeDef",
@@ -519,6 +520,8 @@ GetMetricWidgetImageOutputTypeDef = TypedDict(
     total=False,
 )
 
+LabelOptionsTypeDef = TypedDict("LabelOptionsTypeDef", {"Timezone": str}, total=False)
+
 ListDashboardsOutputTypeDef = TypedDict(
     "ListDashboardsOutputTypeDef",
     {
